Module ask_user
opendev_
tools_
impl
0.1.4
Module ask_
user
Module Items
Structs
In crate opendev_
tools_
impl
opendev_tools_impl
Module
ask_
user
Ask user tool — pose structured questions to the user via a channel.
Structs

AskUser
Tool
Tool for asking the user a question during agent execution.