pub struct LspQueryTool { /* private fields */ }Expand description
Tool that queries language servers for code intelligence.
Supports four actions:
definition— go to definition of a symbol at a positionreferences— find all references to a symbol at a positionhover— get hover information (type info, docs) for a symbol at a positionsymbols— list all symbols in a file (document symbols)
Implementations
Sourceimpl LspQueryTool
impl LspQueryTool
Sourcepub fn new(lsp: Arc<Mutex<LspWrapper>>) -> Self
pub fn new(lsp: Arc<Mutex<LspWrapper>>) -> Self
Create a new LSP query tool with the given LSP wrapper.