pub struct SpawnSubagentTool { /* private fields */ }Expand description
Tool that spawns and runs a subagent to handle an isolated task.
The LLM calls this tool with a subagent type and task description. The tool creates an isolated agent with its own ReAct loop, runs it, and returns the result back to the parent agent.
Implementations
Sourceimpl SpawnSubagentTool
impl SpawnSubagentTool
Sourcepub fn new(
manager: Arc<SubagentManager>,
tool_registry: Arc<ToolRegistry>,
http_client: Arc<AdaptedClient>,
session_dir: PathBuf,
parent_model: impl Into<String>,
working_dir: impl Into<String>,
) -> Self
pub fn new( manager: Arc<SubagentManager>, tool_registry: Arc<ToolRegistry>, http_client: Arc<AdaptedClient>, session_dir: PathBuf, parent_model: impl Into<String>, working_dir: impl Into<String>, ) -> Self
Create a new spawn subagent tool.
Sourcepub fn with_event_sender(self, tx: UnboundedSender<SubagentEvent>) -> Self
pub fn with_event_sender(self, tx: UnboundedSender<SubagentEvent>) -> Self
Set the event channel for progress reporting.
Sourcepub fn with_parent_max_tokens(self, max_tokens: u64) -> Self
pub fn with_parent_max_tokens(self, max_tokens: u64) -> Self
Set the parent agent’s max_tokens (subagents inherit this as fallback).
Sourcepub fn with_parent_reasoning_effort(self, effort: Option<String>) -> Self
pub fn with_parent_reasoning_effort(self, effort: Option<String>) -> Self
Set the parent agent’s reasoning effort (subagents inherit this).