Auto-formatting support for edited files.
Detects system-available formatters (rustfmt, prettier, black, gofmt, etc.) and runs the appropriate one after file write/edit operations.
Structs
- Formatter
Info - Information about a formatter.
Functions
- apply_
config - Apply formatter config overrides from
AppConfig.formatter. - detect_
formatters - Detect which formatters are available on the system. Results are cached after the first call.
- disable_
formatter - Disable a specific formatter by name.
- enable_
formatter - Enable a previously disabled formatter.
- format_
file - Run the appropriate formatter on a file.
- format_
file_ with_ config - Format a file using a custom formatter from config (if available).
- get_
formatter_ for_ file - Get the best formatter for a given file path.
- get_
status - Get status of all formatters.